#!/usr/bin/python
# -*- coding: utf-8 -*-

'''get metadata from metacritic'''

import os, sys
from utils import get_json, requests, formatted_number, int_with_commas, try_parse_int, log_msg, KODI_LANGUAGE, ADDON_ID
import bs4 as BeautifulSoup
from simplecache import use_cache
import arrow
import json
import xbmc
import xbmcaddon



class Metacritic(object):
    '''get metadata from marcalencc'''
    
    def __init__(self, simplecache=None, kodidb=None):
        """Initialize - optionaly provide simplecache object"""
        if not simplecache:
            from simplecache import SimpleCache
            self.cache = SimpleCache()
        else:
            self.cache = simplecache
        if not kodidb:
            if sys.version_info.major == 2:
                from .kodidb import KodiDb
            else:
                from kodidb import KodiDb
            self.kodidb = KodiDb()
        else:
            self.kodidb = kodidb
    
    def get_details_by_title(self, title, media_type=""):
        ''' get marcalencc details by title
            title --> The title of the media to look for (required)
            media_type --> The type of the media: movie/tvshow (required)
        '''
        if "movie" in media_type:
            media_type = "movie"
        if "show" in media_type:
            media_type = "tvshow"
        params = {media_type, title}
        data = self.get_datacc(params)
        return self.map_detailscc(data)
        
    @staticmethod
    def get_datacc(params):
        '''helper method to get data from marcalencc json API'''
        data = get_json('http://api.marcalencc.com/metacritic/',params)
        if data:
            return data
        else:
            return {}

    @use_cache(2)        
    def get_metacritic(self, title, content_type):
        for splitter in [" ", " :",": ", ":"]:
            # replace splitter by kodi default splitter for easier split all later
            title = title.replace(splitter, "-").lower()
            for remover in ['(', ')']:
                title = title.replace(remover, "")
                title = title.replace("--", "-")
        if "movies" in content_type:
            content = ("movie/%s" %  title)
        if "tvshows" in content_type:
            content = ("tv/%s" %  title)
        headers = {'User-agent': 'Mozilla/5.0 (Windows NT 6.1; Win64; x64; rv:47.0) Gecko/20100101 Firefox/47.0'}
        html = ''
        html = requests.get('https://www.metacritic.com/%s' % content, headers=headers, timeout=15).text
        soup = BeautifulSoup.BeautifulSoup(html, features="html.parser")
        for div in soup.find_all("script", type="application/ld+json"):
            for mcc in div:
                data = json.loads(mcc)
                #log_msg("get_metacritic_all - data from json %s -%s" %  (title, data))
                if data:        
                    return self.map_details(data) if data else None

    @staticmethod
    def map_details(data):
        """helper method to map the details received from metacritic to kodi compatible format"""
        result = {}
        if sys.version_info.major == 2:
            for key, value in data.items():
                # filter the N/A values
                if value in ["N/A", "NA"] or not value:
                    continue
                if key == "name":
                    result["title.mc"] = value
                elif key == "description":
                    result["description.mc"] = value
                if data.get("aggregateRating"):
                    if data["aggregateRating"].get("ratingValue"):
                        result["metacritic.rating"] = data["aggregateRating"].get("ratingValue")
                    if data["aggregateRating"].get("ratingCount"):
                        result["metacritic.votes"] = data["aggregateRating"].get("ratingCount")
                if data.get("trailer"):
                    if data["trailer"].get("thumbnailUrl"):
                        result["metacritic.thumb"] = data["trailer"].get("thumbnailUrl")        
        return result

    @staticmethod
    def map_detailscc(data):
        '''helper method to map the details received from marcalencc to kodi compatible format'''
        result = {}
        for key, value in data.iteritems():
            #filter the N/A values
            if value == "N/A" or not value:
                continue
            if key == "Title":
                result["cc.title"] = value
            if key == "Director":
                result["cc.director"] = value
            if key == "ReleaseDate":
                result["cc.release"] = value
            if key == "CriticRating":
                result["criticrating"] = value
            if key == "CriticReviewCount":
                result["criticreviewcount"] = value
            if key == "UserRating":
                result["cc.userrating"] = value
            if key == "UserReviewCount":
                result["cc.userreviewcount"] = value
            elif key == "Studio": 
                result["cc.studio"] = value
        return result